Trait sp1_prover::types::HashableKey

source ·
pub trait HashableKey {
    // Required methods
    fn hash_babybear(&self) -> [BabyBear; 8];
    fn hash_u32(&self) -> [u32; 8];

    // Provided methods
    fn hash_bn254(&self) -> Bn254Fr { ... }
    fn bytes32(&self) -> String { ... }
    fn hash_bytes(&self) -> [u8; 32] { ... }
}
A trait for keys that can be hashed into a digest.

Required Methods

source

fn hash_babybear(&self) -> [BabyBear; 8]

Hash the key into a digest of BabyBear elements.

source

fn hash_u32(&self) -> [u32; 8]

Hash the key into a digest of u32 elements.

Provided Methods

source

fn hash_bn254(&self) -> Bn254Fr

source

fn bytes32(&self) -> String

source

fn hash_bytes(&self) -> [u8; 32]

Hash the key into a digest of bytes elements.

Implementations on Foreign Types

source

impl<SC: StarkGenericConfig<Val = BabyBear, Domain = TwoAdicMultiplicativeCoset<BabyBear>>> HashableKey for StarkVerifyingKey<SC>
where <SC::Pcs as Pcs<SC::Challenge, SC::Challenger>>::Commitment: AsRef<[BabyBear; 8]>,

source

fn hash_babybear(&self) -> [BabyBear; 8]

source

fn hash_u32(&self) -> [u32; 8]

Implementors