pub struct RangeProofs {
pub shard_range: ShardRange,
pub proofs: VecDeque<RecursionProof>,
}Expand description
A collection of recursion proofs covering a contiguous shard range.
The RangeProofs struct encapsulates a series of recursion proofs that together cover a
specific shard range. It provides methods to manipulate and access these proofs, including
downloading their witnesses and converting them to and from artifacts.
Fields
shard_range: ShardRangeproofs: VecDeque<RecursionProof>Implementations
Sourceimpl RangeProofs
impl RangeProofs
pub fn new(shard_range: ShardRange, proofs: VecDeque<RecursionProof>) -> Self
pub fn as_artifacts(self) -> impl Iterator<Item = Artifact> + Send + Sync
pub fn from_artifacts(artifacts: &[Artifact]) -> Result<Self, TaskError>
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn push_right(&mut self, proof: RecursionProof)
pub fn push_left(&mut self, proof: RecursionProof)
pub fn split_off(&mut self, at: usize) -> Option<Self>
pub fn push_both(&mut self, middle: RecursionProof, right: Self)
pub fn range(&self) -> ShardRange
pub async fn download_witness<C: SP1ProverComponents>( &self, is_complete: bool, artifact_client: &impl ArtifactClient, recursion_data: &RecursionProverData<C>, ) -> Result<SP1CircuitWitness, TaskError>
pub async fn try_delete_proofs( &self, artifact_client: &impl ArtifactClient, ) -> Result<(), TaskError>