pub fn normalize_program_from_input(
recursive_verifier: &RecursiveShardVerifier<SP1GlobalContext, RiscvAir<SP1Field>, InnerConfig>,
input: &SP1NormalizeWitnessValues<SP1GlobalContext, SP1PcsProofInner>,
) -> RecursionProgram<SP1Field>Expand description
The program that proves the correct execution of the verifier of a single shard of the core (RISC-V) machine.