Trait sp1_prover::types::HashableKey
source · pub trait HashableKey {
// Required methods
fn hash_babybear(&self) -> [BabyBear; 8];
fn hash_u32(&self) -> [u32; 8];
// Provided methods
fn hash_bn254(&self) -> Bn254Fr { ... }
fn bytes32(&self) -> String { ... }
fn hash_bytes(&self) -> [u8; 32] { ... }
}Expand description
A trait for keys that can be hashed into a digest.
Required Methods
sourcefn hash_babybear(&self) -> [BabyBear; 8]
fn hash_babybear(&self) -> [BabyBear; 8]
Hash the key into a digest of BabyBear elements.
Provided Methods
fn hash_bn254(&self) -> Bn254Fr
fn bytes32(&self) -> String
sourcefn hash_bytes(&self) -> [u8; 32]
fn hash_bytes(&self) -> [u8; 32]
Hash the key into a digest of bytes elements.